"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const initArtemis_1 = __importDefault(require("../lib/initArtemis"));
const apollo_client_1 = require("apollo-client");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const graphql_tools_1 = require("graphql-tools");
const apollo_test_utils_1 = require("apollo-test-utils");
const typeDefs = `
    type User {
        id: Int
        name: String
    }

    type Query {
        user: User
    }
`;
const schema = graphql_tools_1.makeExecutableSchema({ typeDefs });
graphql_tools_1.addMockFunctionsToSchema({ schema });
const mockedNetworkInterface = apollo_test_utils_1.mockNetworkInterface({ schema });
describe("initArtemis", () => {
    it("creates an instance of Apollo Client with no data supplied", () => {
        const basic = initArtemis_1.default({});
        expect(basic).toBeInstanceOf(apollo_client_1.ApolloClient);
    });
    it("creates an instance of Apollo Client with data supplied", () => {
        const mockData = {
            foo: "bar",
            baz: "foo",
        };
        const init = initArtemis_1.default(mockData);
        const apollo = new apollo_client_1.ApolloClient({
            link: mockedNetworkInterface,
            cache: new apollo_cache_inmemory_1.InMemoryCache().restore({ mockData }),
        });
        expect(init).toBeInstanceOf(apollo);
    });
});
